<?php
/**
 * Include and setup custom metaboxes and fields. (make sure you copy this file to outside the CMB2 directory)
 *
 * Be sure to replace all instances of 'yourprefix_' with your project's prefix.
 * http://nacin.com/2010/05/11/in-wordpress-prefix-everything/
 *
 * @category YourThemeOrPlugin
 * @package  Demo_CMB2
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/WebDevStudios/CMB2
 */

/**
 * Get the bootstrap! If using the plugin from wordpress.org, REMOVE THIS!
 */

if ( file_exists( get_template_directory() . '/cmb2/init.php' ) ) {
	require_once get_template_directory() . '/cmb2/init.php';
} elseif ( file_exists( get_template_directory() . '/CMB2/init.php' ) ) {
	require_once get_template_directory() . '/CMB2/init.php';
}

/**
 * Conditionally displays a metabox when used as a callback in the 'show_on_cb' cmb2_box parameter
 *
 * @param  CMB2 object $cmb CMB2 object
 *
 * @return bool             True if metabox should show
 */
function virsky_show_if_front_page( $cmb ) {
	// Don't show this metabox if it's not the front page template
	if ( $cmb->object_id !== get_option( 'page_on_front' ) ) {
		return false;
	}
	return true;
}

/**
 * Conditionally displays a field when used as a callback in the 'show_on_cb' field parameter
 *
 * @param  CMB2_Field object $field Field object
 *
 * @return bool                     True if metabox should show
 */
function virsky_hide_if_no_cats( $field ) {
	// Don't show this field if not in the cats category
	if ( ! has_tag( 'cats', $field->object_id ) ) {
		return false;
	}
	return true;
}

/**
 * Manually render a field.
 *
 * @param  array      $field_args Array of field arguments.
 * @param  CMB2_Field $field      The field object
 */
function virsky_render_row_cb( $field_args, $field ) {
	$classes     = $field->row_classes();
	$id          = $field->args( 'id' );
	$label       = $field->args( 'name' );
	$name        = $field->args( '_name' );
	$value       = $field->escaped_value();
	$description = $field->args( 'description' );
	?>
	<div class="custom-field-row <?php echo esc_attr( $classes ); ?>">
		<p><label for="<?php echo esc_attr( $id ); ?>"><?php echo esc_html( $label ); ?></label></p>
		<p><input id="<?php echo esc_attr( $id ); ?>" type="text" name="<?php echo esc_attr( $name ); ?>" value="<?php echo esc_html( $value ); ?>"/></p>
		<p class="description"><?php echo wp_kses_post( $description ); ?></p>
	</div>
	<?php
}

/**
 * Manually render a field column display.
 *
 * @param  array      $field_args Array of field arguments.
 * @param  CMB2_Field $field      The field object
 */
function virsky_display_text_small_column( $field_args, $field ) {
	?>
	<div class="custom-column-display <?php echo esc_attr( $field->row_classes() ); ?>">
		<p><?php echo wp_kses_post( $field->escaped_value() ); ?></p>
		<p class="description"><?php echo wp_kses_post( $field->args( 'description' ) ); ?></p>
	</div>
	<?php
}

/**
 * Conditionally displays a message if the $post_id is 2
 *
 * @param  array             $field_args Array of field parameters
 * @param  CMB2_Field object $field      Field object
 */
function virsky_before_row_if_2( $field_args, $field ) {
	if ( 2 == $field->object_id ) {
		echo '<p>Testing <b>"before_row"</b> parameter (on $post_id 2)</p>';
	} else {
		echo '<p>Testing <b>"before_row"</b> parameter (<b>NOT</b> on $post_id 2)</p>';
	}
}

add_action( 'cmb2_admin_init', 'virsky_register_metabox' );
/**
 * Hook in and add a demo metabox. Can only happen on the 'cmb2_admin_init' or 'cmb2_init' hook.
 */
function virsky_register_metabox() {
	$prefix = '_virsky_';
	$prefixpage = '_virskypage_';
    
    /********************************\
        page layout select meta 
    \********************************/
    
	$virsky_meta = new_cmb2_box( array(
		'id'            => $prefixpage . 'page_layout_section',
		'title'         => esc_html__( 'Page Layout', 'virtusky' ),
        'context' => 'side',
        'priority' => 'high',
		'object_types'  => array( 'page', ), // Post type
	) );

	$virsky_meta->add_field( array(
		'desc'       => esc_html__( 'Set page layout container,container fluid,fullwidth or both. It\'s work only in bulder page template.', 'virtusky' ),
		'id'         => $prefix . 'custom_page_layout',
		'type'       => 'radio',
        'options' => array(
            '1' => 'Container',
            '2' => 'Container Fluid',
            '3' => 'Fullwidth',
            ),
	) );
	$virsky_meta->add_field( array(
		'name' => esc_html__( 'Top and Bottom Padding', 'virtusky' ),
		'id'   => $prefix . 'custom_page_padding',
		'type' => 'own_slider',
		'min'         => '0',
		'max'         => '500',
		'step'        => '1',
		'default'     => '0', // start value
		'value_label' => 'Value:',
        'desc' => esc_html__( 'Set page content wrapper top and bottom padding.', 'virtusky' ),
	));
    /********************************\
        Page Header and slider meta 
    \********************************/
    
	$virsky_meta = new_cmb2_box( array(
		'id'            => $prefixpage . 'sliderPageheader_section',
		'title'         => esc_html__( 'Page Header Settings', 'virtusky' ),
		'object_types'  => array( 'page' ), // Post type
        'closed'        => true
	) );

	$virsky_meta->add_field( array(
            'name'             => esc_html__( 'Slider/Page Header Active', 'virtusky' ),
            'desc'             => 'Select an option',
            'id'               => $prefix . 'slide_header_active',
            'type'             => 'select',
            'show_option_none' => false,
            'default'          => 'page_header',
            'options'          => array(
                'noheader'     => esc_html__( 'No Header', 'virtusky' ),
                'slider'       => esc_html__( 'Slider', 'virtusky' ),
                'page_header'  => esc_html__( 'Page Header', 'virtusky' ),
                'customslider' => esc_html__( 'Custom Slider', 'virtusky' ),
            ),
        ) 
    
    );
	$virsky_meta->add_field(  array(
        'name'           => esc_html__( 'Custom Slider', 'virtusky' ),
        'desc'           => esc_html__( 'Set custom slider shortcode.', 'virtusky' ),
        'classes'        => 'slider-customShortcode',
        'id'             => $prefix . 'slider-customshortcode',
        'type'           => 'text',
    ) );
	// Slider Select 
	$virsky_meta->add_field(  array(
        'name'           => esc_html__( 'Slider', 'virtusky' ),
        'desc'           => esc_html__( 'Set slider.', 'virtusky' ),
        'classes'        => 'slider-settings',
        'id'             => $prefix . 'slider-shortcode',
        'type'           => 'select',
        // Use a callback to avoid performance hits on pages where this field is not displayed (including the front-end).
        'options_cb'     => 'virsky_get_slider_shortcode_options',
        // Same arguments you would pass to `get_terms`.
        'get_post_type' => array(
            'post_type'   => 'virsky_slider',
            ),
    ) );
	$virsky_meta->add_field( array(
            'name'             => esc_html__( 'Page Header Settings', 'virtusky' ),
            'desc'             => 'Select page header settings type. Global settings set from theme options.',
            'id'               => $prefix . 'slide_header_settings',
            'type'             => 'select',
            'classes'          => 'pageset page-header-settings',
            'show_option_none' => false,
            'default'          => 'global',
            'options'          => array(
                'pageset'       => esc_html__( 'Page Settings', 'virtusky' ),
                'global'        =>  esc_html__( 'Global Settings', 'virtusky' ),
            ),
        ) 
    
    );

	$virsky_meta->add_field( array(
		'name' => esc_html__( 'Header Background Color', 'virtusky' ),
		'id'   => $prefix . 'header-bgcolor',
		'type' => 'colorpicker',
		'classes' => 'pageset page-setting',
	));
	
	$virsky_meta->add_field( array(
		'name' => esc_html__( 'Background Image', 'virtusky' ),
		'desc' => esc_html__( 'Set background image.', 'virtusky' ),
		'id'   => $prefix . 'header_bgimg',
        'classes' => 'pageset page-setting',
		'type' => 'file',
	));
	
	$virsky_meta->add_field( array(
		'name' => esc_html__( 'Overlay', 'virtusky' ),
		'desc' => esc_html__( 'Set overlay.', 'virtusky' ),
		'id'   => $prefix . 'header_overlay',
        'classes' => 'pageset page-setting',
		'type' => 'checkbox',
	));
	
	$virsky_meta->add_field( array(
		'name' => esc_html__( 'Overlay Color', 'virtusky' ),
		'desc' => esc_html__( 'Set overlay color.', 'virtusky' ),
		'id'   => $prefix . 'header_overlaycolor',
        'classes' => 'pageset page-setting',
		'type' => 'colorpicker',
	));
	
	$virsky_meta->add_field( array(
		'name' => esc_html__( 'Overlay Opacity', 'virtusky' ),
		'desc' => esc_html__( 'Set overlay opacity.', 'virtusky' ),
		'id'   => $prefix . 'header_overlayopacity',
        'classes' => 'pageset page-setting',
		'type' => 'own_slider',
		'min'         => '0',
		'max'         => '1',
		'step'        => '0.1',
		'default'     => '0', // start value
		'value_label' => 'Value:',
        'desc' => esc_html__( 'Default opacity 0.5', 'virtusky' ),
	));
	
	
	$virsky_meta->add_field( array(
		'name' => esc_html__( 'Header Text Color', 'virtusky' ),
		'id'   => $prefix . 'header-textcolor',
		'classes' => 'pageset page-setting',
		'type' => 'colorpicker',
	));
	
    /***************************************************************\
                            Post type meta
    \***************************************************************/
    
    
    /******************\
      Slider section 
    \******************/
    
	$virsky_meta = new_cmb2_box( array(
		'id'            => $prefix . 'slider_section',
		'title'         => esc_html__( 'Slider Settings', 'virtusky' ),
		'object_types'  => array( 'virsky_slider' ), // Post type
        'closed'        => true
	) );
	
	$virsky_meta->add_field( array(
		'name' => esc_html__( 'Slider Pagination Options', 'virtusky' ),
		'id'   => $prefix . 'slider-paginav',
		'type' => 'radio_inline',
        'options'    => array(
			'no'  	=> esc_html__( 'No Pagination', 'virtusky' ),
			'nav'   => esc_html__( 'Slider Navigation', 'virtusky' ),
			'pagi'  => esc_html__( 'Slider Pagination', 'virtusky' )
		),
        'default' => 'no'
	));
	$virsky_meta->add_field( array(
		'name' => esc_html__( 'Slider Speed', 'virtusky' ),
		'id'   => $prefix . 'slider-slidspeed',
		'desc' => esc_html__( 'Set slider speed. Default speed 4000.', 'virtusky' ),
		'classes'     => 'slider-opt',
		'type' => 'text_small',
	));
	
	// Slider Group
	$group_field_id = $virsky_meta->add_field( array(
		'id'          => $prefix . 'slider-group-options',
        'classes'     => 'slider-opt',
		'type'        => 'group',
		'description' => esc_html__( 'Add Slider', 'virtusky' ),
		'options'     => array(
			'group_title'   => esc_html__( 'Slider {#}', 'virtusky' ), // {#} gets replaced by row number
			'add_button'    => esc_html__( 'Add Slider', 'virtusky' ),
			'remove_button' => esc_html__( 'Remove Slider', 'virtusky' ),
			'sortable'      => false, // beta
			'closed'     => true, // true to have the groups closed by default
            
		),
	) );
    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Overlay', 'virtusky' ),
		'desc' => esc_html__( 'Set overlay.', 'virtusky' ),
		'id'   => $prefix . 'slider_overlay',
        'classes' => 'slider-media',
		'type' => 'checkbox',
	) );
    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Overlay Color', 'virtusky' ),
		'desc' => esc_html__( 'Set overlay color.', 'virtusky' ),
		'id'   => $prefix . 'slider_overlaycolor',
        'classes' => 'slider-media',
		'type' => 'colorpicker',
	) );
    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Overlay Opacity', 'virtusky' ),
		'desc' => esc_html__( 'Set overlay opacity.', 'virtusky' ),
		'id'   => $prefix . 'slider_overlayopacity',
        'classes' => 'slider-media',
		'type' => 'own_slider',
		'min'         => '0',
		'max'         => '1',
		'step'        => '0.1',
		'default'     => '0', // start value
		'value_label' => 'Value:',
        'desc' => esc_html__( 'Default opacity 0.5', 'virtusky' ),
	) );
    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Text Color One', 'virtusky' ),
		'desc' => esc_html__( 'Set text color one.', 'virtusky' ),
        'classes' => 'slider-media',
		'id'   => $prefix . 'slider_contentcolor',
		'type' => 'colorpicker',
	) );
    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Text Color Two', 'virtusky' ),
		'desc' => esc_html__( 'Set text color two.', 'virtusky' ),
        'classes' => 'slider-media',
		'id'   => $prefix . 'slider_contentcolortwo',
		'type' => 'colorpicker',
	) );
	$virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Description Color', 'virtusky' ),
		'desc' => esc_html__( 'Set Description color.', 'virtusky' ),
        'classes' => 'slider-media',
		'id'   => $prefix . 'slider_descriptioncolor',
		'type' => 'colorpicker',
	) );

    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Button Text Color', 'virtusky' ),
		'desc' => esc_html__( 'Set Button text color.', 'virtusky' ),
        'classes' => 'slider-media',
		'id'   => $prefix . 'slider_anchorcolor',
		'type' => 'colorpicker',
	) );
    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Button Hover Text  Color', 'virtusky' ),
		'desc' => esc_html__( 'Set button hover text color.', 'virtusky' ),
        'classes' => 'slider-media',
		'id'   => $prefix . 'slider_anchorhovercolor',
		'type' => 'colorpicker',
	) );
    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Button Background Color', 'virtusky' ),
		'desc' => esc_html__( 'Set button background color.', 'virtusky' ),
        'classes' => 'slider-media',
		'id'   => $prefix . 'slider_anchorbgcolor',
		'type' => 'colorpicker',
	) );
    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Button Hover Background Color', 'virtusky' ),
		'desc' => esc_html__( 'Set button hover background color.', 'virtusky' ),
        'classes' => 'slider-media',
		'id'   => $prefix . 'slider_anchorhoverbgcolor',
		'type' => 'colorpicker',
	) );

    
    // Slider group

    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Background Image', 'virtusky' ),
		'id'   => $prefix . 'slider-bg',
		'classes' => 'slider-media',
		'type' => 'file',
	) );
	$virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Video Background', 'virtusky' ),
		'desc' => esc_html__( 'Set youtube video id.', 'virtusky' ),
		'id'   => $prefix . 'slider-videobg',
		'classes' => 'slider-media',
		'type' => 'text',
	) );
	$virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Text Show Middle', 'virtusky' ),
		'desc' => esc_html__( 'Show Only text in middle.', 'virtusky' ),
		'id'   => $prefix . 'slider_textmeddle',
        'classes' => 'slider-content',
		'type' => 'checkbox',
	) );
    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Text One', 'virtusky' ),
		'id'   => $prefix . 'slider-text',
		'classes' => 'slider-content',
		'type' => 'text',
	) );
    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Text Two', 'virtusky' ),
		'id'   => $prefix . 'slider-texttwo',
		'classes' => 'slider-content',
		'type' => 'text',
	) );
    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Descriptions', 'virtusky' ),
		'id'   => $prefix . 'slider-descriptions',
		'classes' => 'slider-content',
		'type' => 'text',
	) );
	
    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Button Text', 'virtusky' ),
		'id'   => $prefix . 'sliderbutton-text',
		'classes' => 'slider-content',
		'type' => 'text',
	) );
    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Button Url', 'virtusky' ),
		'id'   => $prefix . 'sliderbutton-url',
		'classes' => 'slider-content',
		'type' => 'text',
	) );
    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Button Target', 'virtusky' ),
		'id'   => $prefix . 'slider-target',
		'classes' => 'slider-content',
		'type' => 'select',
        'options'    => array(
			'_self'  	=> esc_html__( 'Self', 'virtusky' ),
			'_blank'  	=> esc_html__( 'Blank', 'virtusky' ),
			'_parent'   => esc_html__( 'Parent', 'virtusky' ),
			'_top'  	=> esc_html__( 'Top', 'virtusky' )
		),
	) );
	$virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Image Position', 'virtusky' ),
		'id'   => $prefix . 'slider-imgpos',
		'classes' => 'slider-content',
		'type' => 'radio_inline',
        'options'    => array(
			'no'  => esc_html__( 'No Image', 'virtusky' ),
			'left'   => esc_html__( 'Left', 'virtusky' ),
			'right'  => esc_html__( 'Right', 'virtusky' )
		),
        'default' => 'left'
	) );
    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Image', 'virtusky' ),
		'id'   => $prefix . 'slider-img',
		'desc' => esc_html__( 'Make sure Text show meddle check box is unchecked to show image.', 'virtusky' ),
		'classes' => 'slider-content',
		'type' => 'file',
	) );
	// Nav Text
    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Nav Text One', 'virtusky' ),
		'id'   => $prefix . 'slider-navtextone',
		'classes' => 'slider-content',
		'type' => 'text',
	) );
	
    $virsky_meta->add_group_field( $group_field_id, array(
		'name' => esc_html__( 'Nav Text Two', 'virtusky' ),
		'id'   => $prefix . 'slider-navtexttwo',
		'classes' => 'slider-content',
		'type' => 'text',
	) );
        
}
