<?php
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "virsky_opt";

    // This line is only for altering the demo. Can be easily removed.
    $opt_name = apply_filters( 'redux_demo/opt_name', $opt_name );

    /*
     *
     * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
     *
     */

    $sampleHTML = '';
    if ( file_exists( get_template_directory() . '/info-html.html' ) ) {
        Redux_Functions::initWpFilesystem();

        global $wp_filesystem;

        $sampleHTML = $wp_filesystem->get_contents( get_template_directory(). '/info-html.html' );
    }
	
	$alowhtml = array(
		'p' => array(
			'class' => array()
		),
		'span' => array()
	);

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => esc_html__( 'VirtuSky Options', 'virtusky' ),
        'page_title'           => esc_html__( 'VirtuSky Options', 'virtusky' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => true,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        // HINTS 
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */


    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => esc_html__( 'Theme Information 1', 'virtusky' ),
            'content' => wp_kses( __( '<p>This is the tab content, HTML is allowed.</p>', 'virtusky' ), $alowhtml )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => esc_html__( 'Theme Information 2', 'virtusky' ),
            'content' => wp_kses( __( '<p>This is the tab content, HTML is allowed.</p>', 'virtusky' ), $alowhtml )
        )
    );
    Redux::set_help_tab( $opt_name, $tabs );

    // Set the help sidebar
    $content = wp_kses( __('<p>This is the sidebar content, HTML is allowed.</p>', 'virtusky' ), $alowhtml );
    Redux::set_help_sidebar( $opt_name, $content );

    // -> START General Fields

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'General', 'virtusky' ),
        'id'               => 'virsky_general',
        'customizer_width' => '450px',
        'icon'             => 'el el-cog',
        'fields'           => array(
            
            array(
                'id'       => 'virsky_display_preloader',
                'type'     => 'switch',
                'title'    => esc_html__( 'Display Preloader', 'virtusky' ),
                'subtitle' => esc_html__( 'Switch On to Display Preloader.', 'virtusky' ),
                'default'  => true,
            ),
            array(
                'id'       => 'virsky_display_bcktotop',
                'type'     => 'switch',
                'title'    => esc_html__( 'Display Back To Top Button', 'virtusky' ),
                'subtitle' => esc_html__( 'Switch On to Display back to top button.', 'virtusky' ),
                'default'  => true,
            ),
            array(
                'id'       => 'virsky_enable_breadcrumb',
                'type'     => 'switch',
                'title'    => esc_html__( 'Breadcrumb Hide/Show', 'virtusky' ),
                'subtitle' => esc_html__( 'Hide / Show breadcrumb from all page and post ( Default settings hide ).', 'virtusky' ),
                'default'  => '1',
				'on'	   => 'Hide',
				'off'	   => 'Show',
            ),
            array(
                'id'          => 'virsky_virsky_body_fonts',
                'type'        => 'typography', 
                'title'       => esc_html__('Body Typography', 'virtusky'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array( 'body', 'p' ),
                'units'       =>'px',
                'subtitle'    => esc_html__('Typography option with each property can be called individually.', 'virtusky'),
                'text-align'  => false,
                'line-height' => false,
                'font-backup' => false,
                'color'       => false,
                'font-size'   => false,
                'subsets'     => false,
                'line-height' => false,
                'default'     => array(
                    'font-family' => 'Roboto', 
                    'google'      => true,
                ),
            ),
            array(
                'id'          => 'virsky_virsky_header_fonts',
                'type'        => 'typography', 
                'title'       => esc_html__('Heading Typography', 'virtusky'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h1', 'h2', 'h3', 'h4', 'h5', 'h6', '.whmcs-template-five h1', '.whmcs-template-five h2', '.whmcs-template-five h3', '.whmcs-template-five h4', '.whmcs-template-five h5', '.whmcs-template-five h6' ),
                'units'       => 'px',
                'subtitle'    => esc_html__('Typography option with each property can be called individually.', 'virtusky'),
                'text-align'  => false,
                'line-height' => false,
                'font-backup' => false,
                'color'       => false,
                'font-size'   => false,
                'subsets'     => false,
                'line-height' => false,
                'default'     => array(
                    'font-family' => 'Roboto', 
                    'google'      => true,

                ),
            ),
            array(
                'id'       => 'virsky_unlimited-color',
                'type'     => 'color',
                'title'    => esc_html__('Custom Theme Color', 'virtusky'), 
                'subtitle' => esc_html__('Pick a unlimited mian color for the theme (default: #288feb).', 'virtusky'),
                'default'  => '#288feb',
                'validate' => 'color'
            ),
			array(
                'id'       => 'virsky_map_apikey',
                'type'     => 'text',
                'title'    => __( 'API Key', 'virtusky' ),
                'subtitle' => __( 'Set your google map api key', 'virtusky' )              
            ),
         
        )
    ) );
    
    /* End General Fields */


    
    // -> START Header / Menu
    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Header', 'virtusky'),
        'id'         => 'virsky_header_option',
        'icon'       => 'el el-credit-card',
        'fields'     => array(    
            array(
                'id'       => 'virsky_site_logo',
                'type'     => 'media',
                'url'      => true,
                'title'    => esc_html__( 'Logo', 'virtusky' ),
                'compiler' => 'true',
                'subtitle' => esc_html__( 'Upload your site logo for header Version one ( recommendation png format ).', 'virtusky' ),
            ),
			array(
                'id'       => 'virsky_site_logo_dimensions',
                'type'     => 'dimensions',
                'output'   => array( '.navbar-brand' ),
                'units'    => array('em','px','%'),
                'title'    => __('Logo Dimensions (Width/Height).', 'virtusky'),
                'subtitle' => __('Set logo dimensions to choose width, height, and unit.', 'virtusky'),
                'default'  => array(
                    'Width'   => '100', 
                    'Height'  => '50'
                ),
            ),
			array(
                'id'       => 'virsky_site_logomargin_dimensions',
                'type'     => 'spacing',
				'mode'           => 'margin',
                'output'   => array( '#secondaryMenu a.navbar-brand' ),
				'units_extended' => 'false',
                'units'    => array('em','px' ),
                'title'    => __('Logo Top and Bottom Margin.', 'virtusky'),
				'left'     => false,
                'right'    => false,
                'subtitle' => __('Set logo top and bottom margin.', 'virtusky'),
                'default'            => array(
                    'margin-top'     => '25px',
                    'margin-bottom'  => '0px',
                    'units'           => 'px' 
                )
            ),
			array(
                'id'             => 'virsky_menu_dimensions',
                'type'           => 'spacing',
                'output'         => array('.secondary-menu-links li > a', '.menu-toggle-btn'),
                'mode'           => 'padding',
                'units'          => array('em', 'px'),
                'units_extended' => 'false',
                'title'          => __('Menu Links Padding ( top/bottom )', 'virtusky'),
                'subtitle'       => __('Set menu links top/bottom padding.', 'virtusky'),
                'left'           => false,
                'right'          => false,
                'default'            => array(
                    'padding-top'     => '31px',
                    'padding-bottom'  => '24px',
                    'units'           => 'px' 
                )
            ),
			array(
                'id'             => 'virsky_menu_responsive_dimensions',
                'type'           => 'spacing',
                'output'         => array( '.menu-toggle-btn' ),
                'mode'           => 'padding',
                'units'          => array( 'em', 'px' ),
                'units_extended' => 'false',
                'title'          => __('Responsive Menu Padding ( top/bottom )', 'virtusky'),
                'subtitle'       => __('Set responsive menu links top/bottom padding.', 'virtusky'),
                'default'            => array(
                    'padding-left'    => '32px',
                    'padding-right'   => '0px',
                    'padding-top'     => '36px',
                    'padding-bottom'  => '29px',
                    'units'           => 'px' 
                )
            ),
            array( 
                'id'       => 'virsky_site_title',
                'type'     => 'text',
                'validate' => 'html',
                'title'    => esc_html__( 'Text Logo', 'virtusky' ),
                'subtitle' => esc_html__( 'Write your logo text use as logo ( You can use span tag for text color ).', 'virtusky' ),
                'default'  => wp_kses( __( '<span>Virtu</span>Sky', 'virtusky' ), $alowhtml ),
            ),
            array(
                'id'   =>'divider_headerpromobar',
                'type' => 'divide'
            ),
            array(
                'id'       => 'virsky_header_promo',
                'type'     => 'switch',
                'title'    => esc_html__( 'Display Header Promo Bar', 'virtusky' ),
                'subtitle' => esc_html__( 'Switch on to display header promotion bar.', 'virtusky' ),
                'default'  => false,
            ),
			array(
				'id'          => 'virsky_header_promo_text',
				'type'        => 'text',
				'title'       => esc_html__('Promotion text', 'virtusky'), 
				'subtitle'    => esc_html__('Set Promotion text.', 'virtusky'),
				'required' => array( 'virsky_header_promo', 'equals', true  ),
			),
			array(
				'id'          => 'virsky_header_promo_date',
				'type'        => 'date',
				'title'       => esc_html__('Date Option', 'virtusky'), 
				'subtitle'    => esc_html__('Set Promotion date.', 'virtusky'),
				'placeholder' => 'Click to enter a date',
				'required' => array( 'virsky_header_promo', 'equals', true  ),
			),
            array(
                'id'       => 'virsky_header_promo_btn_text',
                'type'     => 'text',
                'title'    => esc_html__( 'Promotion Button Text', 'virtusky' ),
                'subtitle' => esc_html__( 'Set promotion button text.', 'virtusky' ),
				'required' => array( 'virsky_header_promo', 'equals', true  ),
                'default'  => 'Click Here',
            ),
            array(
                'id'       => 'virsky_header_promo_btn_url',
                'type'     => 'text',
                'title'    => esc_html__( 'Promo Button URL', 'virtusky' ),
				'required' => array( 'virsky_header_promo', 'equals', true  ),
                'subtitle' => esc_html__( 'Set promo button URL.', 'virtusky' ),
                'default'  => '#',
            ),
            array(
                'id'       => 'virsky_header_promo_bg',
                'type'     => 'background',
				'output'   => array( '#promo' ),
                'title'    => esc_html__( 'Promo Background color', 'virtusky' ),
				'required' => array( 'virsky_header_promo', 'equals', true  ),
                'subtitle' => esc_html__( 'Set promo backgroung color.', 'virtusky' )
            ),
            array(
                'id'       => 'virsky_header_promo_color',
                'type'     => 'color',
				'output'   => array( '#promo p', '#promo button.close'  ),
                'title'    => esc_html__( 'Promo Text Color', 'virtusky' ),
				'required' => array( 'virsky_header_promo', 'equals', true  ),
                'subtitle' => esc_html__( 'Set promo text color.', 'virtusky' ),
            ),
            array(
                'id'   =>'divider_headertop',
                'type' => 'divide',
				'required' => array( 'virsky_header_promo', 'equals', true  ),
            ),
            array(
                'id'       => 'virsky_header_top',
                'type'     => 'switch',
                'title'    => esc_html__( 'Display Header Top', 'virtusky' ),
                'subtitle' => esc_html__( 'Switch on to display header top.', 'virtusky' ),
                'default'  => true,
            ),
            array(
                'id'       => 'virsky_header_social',
                'type'     => 'switch',
                'title'    => esc_html__( 'Display Header Social', 'virtusky' ),
                'subtitle' => esc_html__( 'Switch on to display header social media.', 'virtusky' ),
                'default'  => true,
				'required' => array( 'virsky_header_top', 'equals', true  ),
            ),
            array(
                'id'       => 'virsky_header_phonemail',
                'type'     => 'switch',
                'title'    => esc_html__( 'Display Phone & Email', 'virtusky' ),
				'required' => array( 'virsky_header_top', 'equals', true  ),
                'subtitle' => esc_html__( 'Switch on to display header phone and email.', 'virtusky' ),
                'default'  => true,
            ),
            array(
                'id'       => 'virsky_header_text',
                'type'     => 'text',
                'title'    => esc_html__( 'Text', 'virtusky' ),
                'subtitle' => esc_html__( 'Set header top text.', 'virtusky' ),
                'required' => array( 'virsky_header_phonemail', 'equals', true  )
            ),
            array(
                'id'       => 'virsky_header_mobile',
                'type'     => 'text',
                'title'    => esc_html__( 'Phone Number', 'virtusky' ),
                'subtitle' => esc_html__( 'Set header top phone number.', 'virtusky' ),
                'required' => array( 'virsky_header_phonemail', 'equals', true  )
            ),
            array(
                'id'       => 'virsky_header_email',
                'type'     => 'text',
                'title'    => esc_html__( 'Email', 'virtusky' ),
                'subtitle' => esc_html__( 'Set header top email.', 'virtusky' ),
                'required' => array( 'virsky_header_phonemail', 'equals', true  )
            ),
            array(
                'id'       => 'virsky_headertop_bgcolor',
                'type'     => 'background',
                'output'   => array( '#primaryMenu' ),
                'title'    => esc_html__( 'Header Top Background', 'virtusky' ),
                'subtitle' => esc_html__( 'Set header top background color.', 'virtusky' ),
				'background-image' 		=> false,
				'background-size' 		=> false,
				'background-attachment' => false,
				'background-repeat' 	=> false,
				'background-position' 	=> false,
				'preview' 				=> false,
				'required' => array( 'virsky_header_top', 'equals', true  ),
                'default'  => array(
                    'background-color' => '#202736',
                ),
            ),
            array(
                'id'       => 'virsky_headertop_color',
                'type'     => 'color',
                'output'   => array( '#primaryMenu', '.primary-menu-links li a', '.primary-social-menu-links a' ),
                'title'    => esc_html__( 'Header Top Text Color', 'virtusky' ),
                'subtitle' => esc_html__( 'Set header top color.', 'virtusky' ),
				'required' => array( 'virsky_header_top', 'equals', true  ),
            ),
            array(
                'id'   =>'divider_headermenu',
                'type' => 'divide',
				'required' => array( 'virsky_header_top', 'equals', true  ),
            ),
            array(
                'id'       => 'virsky_headermenu_bgcolor',
                'type'     => 'background',
                'output'   => array( '#secondaryMenu' ),
                'title'    => esc_html__( 'Header Menu Background', 'virtusky' ),
                'subtitle' => esc_html__( 'Set header menu background color.', 'virtusky' ),
				'background-image' 		=> false,
				'background-size' 		=> false,
				'background-attachment' => false,
				'background-repeat' 	=> false,
				'background-position' 	=> false,
				'preview' 				=> false,
                'default'  => array(
                    'background-color' => '#fff',
                ),
            ),
            array(
                'id'       => 'virsky_header_menu_color',
                'type'     => 'color',
				'output'   => array( '.secondary-menu-links li a', '.menu-toggle-btn' ),
                'title'    => esc_html__( 'Menu Color', 'virtusky' ),
                'subtitle' => esc_html__( 'Set header menu color.', 'virtusky' ),
            ),
            array(
                'id'       => 'virsky_header_menuhov_color',
                'type'     => 'color',
				'output'   => array( '.secondary-menu-links li a:hover', '.secondary-menu-links li a:focus', '.secondary-menu-links .open > a', '.secondary-menu-links .open > a:hover', '.secondary-menu-links .open > a:focus', '.secondary-menu-links li.active > a', '.secondary-menu-links li.active > a:hover','#secondaryMenu button.menu-toggle-btn:hover','#secondaryMenu button.menu-toggle-btn:focus' ),
                'title'    => esc_html__( 'Menu Hover Color', 'virtusky' ),
                'subtitle' => esc_html__( 'Set header menu hover color.', 'virtusky' ),
            ),
            array(
                'id'   =>'divider_logsing',
                'type' => 'divide',
				'required' => array( 'virsky_header_top', 'equals', true  ),
            ),
            array(
                'id'       => 'virsky_off_canvas_menu',
                'type'     => 'switch',
                'title'    => esc_html__( 'Display Off Canvas Menu', 'virtusky' ),
                'subtitle' => esc_html__( 'Switch on to display header off canvas menu.', 'virtusky' ),
                'default'  => true,
            ),
			array(
                'id'       => 'virsky_off_canvas_logo',
                'type'     => 'media',
                'url'      => true,
                'title'    => esc_html__( 'Off Canvas Menu Logo', 'virtusky' ),
                'compiler' => 'true',
                'subtitle' => esc_html__( 'Upload your site logo for header Version one ( recommendation png format ).', 'virtusky' ),
				'required' => array( 'virsky_off_canvas_menu', 'equals', true  ),
            ),
            array(
                'id'       => 'virsky_off_canvas_textlogo',
                'type'     => 'text',
                'validate' => 'html',
                'title'    => esc_html__( 'Off Canvas Menu Text Logo', 'virtusky' ),
                'subtitle' => esc_html__( 'Write your logo text use as logo ( You can use span tag for text color ).', 'virtusky' ),
                'default'  => wp_kses( __( '<span>Virtu</span>Sky', 'virtusky' ), $alowhtml ),
				'required' => array( 'virsky_off_canvas_menu', 'equals', true  ),
            ),
            array(
                'id'       => 'virsky_header_logsing',
                'type'     => 'switch',
                'title'    => esc_html__( 'Display Login/Signup Button', 'virtusky' ),
                'subtitle' => esc_html__( 'Switch on to display header Login/Signup button.', 'virtusky' ),
                'default'  => false,
				'required' => array( 'virsky_off_canvas_menu', 'equals', true  ),
            ),
            array(
                'id'       => 'virsky_header_loginText',
                'type'     => 'text',
                'title'    => esc_html__( 'Login Button Text', 'virtusky' ),
                'subtitle' => esc_html__( 'Set login button text.', 'virtusky' ),
                'default'  => 'Login',
                'required' => array( 'virsky_header_logsing', 'equals', true  )
            ),
            array(
                'id'       => 'virsky_header_loginUrl',
                'type'     => 'text',
                'title'    => esc_html__( 'Login Url', 'virtusky' ),
                'subtitle' => esc_html__( 'Set login button url.', 'virtusky' ),
                'default'  => '#',
                'required' => array( 'virsky_header_logsing', 'equals', true  )
            ),
            array(
                'id'       => 'virsky_header_offcanv_color',
                'type'     => 'color',
				'output'   => array( '.off-canvas-menu .nav li a' ),
                'title'    => esc_html__( 'Off Canvas Menu Color', 'virtusky' ),
                'subtitle' => esc_html__( 'Set off canvas menu color.', 'virtusky' ),
                'required' => array( 'virsky_off_canvas_menu', 'equals', true  )
            ),
			array(
				'id'       => 'virsky_header_offcanv_hide',
				'type'     => 'select',
				'multi'    => true,
				'title'    => __('Hide Off Canvas Menu', 'virtusky'), 
				'desc'     => __('Set which device you want to hide off canvas menu.', 'virtusky'),
				'required' => array( 'virsky_off_canvas_menu', 'equals', true  ),
				//Must provide key => value pairs for radio options
				'options'  => array(
					'1' => 'Hide Desktop',
					'2' => 'Hide Tablate',
					'3' => 'Hide Mobile',
					),
				'default' => 1
			),
			// Header Sticky Option
            array(
                'id'       => 'virsky_header_sticky',
                'type'     => 'image_select',
                'title'    => __( 'Select Header Sticky Element', 'virtusky' ),
                'subtitle' => __( 'Choose which element you want to on sticky.', 'virtusky' ),
                'options'  => array(
                    'stickymenubar' => array(
                        'alt' => '1 Header',
                        'img' => get_template_directory_uri(). '/img/sticky-menu-bar.png'
                    ),
                    'stickytopmenubar' => array(
                        'alt' => '2 Header',
                        'img' =>  get_template_directory_uri(). '/img/sticky-top-menu-bar.png'
                    ),
                    'stickypromomenubar' => array(
                        'alt' => '3 Header',
                        'img' =>  get_template_directory_uri(). '/img/sticky-promo-menu-bar.png'
                    ),
                    'stickypromotopmenubar' => array(
                        'alt' => '4 Header',
                        'img' =>  get_template_directory_uri(). '/img/sticky-promo-top-menu-bar.png'
                    ),
                    'stickypromotopbar' => array(
                        'alt' => '5 Header',
                        'img' =>  get_template_directory_uri(). '/img/sticky-promo-top-bar.png'
                    ),
                    'stickytopbar' => array(
                        'alt' => '6 Header',
                        'img' =>  get_template_directory_uri(). '/img/sticky-top-bar.png'
                    ),
                    'stickypromobar' => array(
                        'alt' => '7 Header',
                        'img' =>  get_template_directory_uri(). '/img/sticky-promo-bar.png'
                    ),
                ),
                'default'  => '1',
            ),



			
    
        ),

    ) );
    
    /* End Header */ 
    
    // -> START Page Header
    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Page Header', 'virtusky'),
        'id'         => 'virsky_pageheader_option',
        'icon'       => 'el el-credit-card',
        'fields'     => array(    
            array(
                'id'       => 'virsky_allHeader_bg',
                'type'     => 'background',
				'output'   => array( '#pageTitle.globpageheader' ),
                'title'    => esc_html__( 'Common Header Background', 'virtusky' ),
                'subtitle' => esc_html__( 'Set common header background.', 'virtusky' ),
				'default'  => array(
					'background-color' => '#428cd6'
				)
            ),
            array(
                'id'       => 'virsky_allHeader_overlay',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Page Header Overlay', 'virtusky' ),
                'subtitle' => esc_html__( 'Check this check box to use overlay.', 'virtusky' ),
            ),                   
            array(
                'id'       => 'virsky_allHeader_ovbg',
                'type'     => 'color',
                'title'    => esc_html__( 'Page Header Overlay Background', 'virtusky' ),
                'subtitle' => esc_html__( 'Set overlay background.', 'virtusky' ),
            ),                                      
            array(
                'id' => 'virsky_allHeader_ovopacity',
                'type' => 'slider',
                'title' => esc_html__('Overlay Opacity', 'virtusky'),
                'subtitle' => esc_html__('Set overlay opacity.', 'virtusky'),
                "default" => .5,
                "min" => 0,
                "step" => .1,
                "max" => 1,
                'resolution' => 0.1,
                'display_value' => 'text'
            ),
            array(
                'id'       => 'virsky_allHeader_textcolor',
                'type'     => 'color',
				'output'   => array( '#pageTitle.globpageheader .section-title h2', '#pageTitle.globpageheader .breadcrumb li a','#pageTitle.globpageheader .breadcrumb li:before', '#pageTitle .breadcrumb span' ),
                'title'    => esc_html__( 'Page Header Text Color', 'virtusky' ),
                'subtitle' => esc_html__( 'Set page header text color.', 'virtusky' ),
            ),             
        ),

    ) );
    
    /* End Header */    
    
    // -> START Blog Page

    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Blog', 'virtusky' ),
        'id'         => 'virsky_blog_page',
        'icon'  => 'el el-blogger',
        'fields'     => array(
      
            array(
                'id'       => 'virsky_blog_sidebar',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Select blog layout', 'virtusky' ),
                'subtitle' => esc_html__( 'Choose your blog sidebar layout ', 'virtusky' ),
                //Must provide key => value(array:title|img) pairs for radio options
                'options'  => array(
                    '1' => array(
                        'alt' => '1 Column',
                        'img' => ReduxFramework::$_url . 'assets/img/1col.png'
                    ),
                    '2' => array(
                        'alt' => '2 Column Left',
                        'img' => ReduxFramework::$_url . 'assets/img/2cl.png'
                    ),
                    '3' => array(
                        'alt' => '2 Column Right',
                        'img' => ReduxFramework::$_url . 'assets/img/2cr.png'
                    ),

                ),
                'default'  => '3'
            ),
            array(
                'id'       => 'virsky_front_blogPost_excerpt',
                'type'     => 'text',
                'title'    => esc_html__( 'Front Posts Excerpt', 'virtusky' ),
                'subtitle' => esc_html__( 'How many word you want to show per post in blog section', 'virtusky' ),
                'default'  => '30',
            ),
            array(
                'id'       => 'virsky_blog_postExcerpt',
                'type'     => 'text',
                'title'    => esc_html__( 'Blog Posts Excerpt', 'virtusky' ),
                'subtitle' => esc_html__( 'How many word you want to show per post in blog ', 'virtusky' ),
                'default'  => '30',
            ), 
            array(
                'id'       => 'virsky_hide_shareBox',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'social share box show/hide', 'virtusky' ),
                'subtitle' => esc_html__( 'Uncheck to hide social share-box in single post view', 'virtusky' ),
                'default'  => '0'// 1 = on | 0 = off
            ),          
        ),
    ) );
    
    /* End blog Page */    
    
    // -> START Page Option

    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Page', 'virtusky' ),
        'id'         => 'virsky_page_page',
        'icon'  => 'el el-file',
        'fields'     => array(
			array(
				'id'       => 'virsky_page_layoutopt',
				'type'     => 'button_set',
				'title'    => esc_html__('Overlay', 'virtusky'),
				'subtitle' => esc_html__('Set page header background overlay.', 'virtusky'),
				//Must provide key => value pairs for options
				'options' => array(
					'1' => esc_html__( 'No sidebar', 'virtusky' ), 
					'2' => esc_html__( 'Page Sidebar', 'virtusky' ), 
					'3' => esc_html__( 'Blog Sidebar', 'virtusky' )
				 ), 
				'default' => '2'
			),
            array(
                'id'       => 'virsky_page_sidebar',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Select Page layout', 'virtusky' ),
                'subtitle' => esc_html__( 'Choose your page sidebar layout ', 'virtusky' ),
                //Must provide key => value(array:title|img) pairs for radio options
                'options'  => array(
                    '1' => array(
                        'alt' => '1 Column',
                        'img' => ReduxFramework::$_url . 'assets/img/1col.png'
                    ),
                    '2' => array(
                        'alt' => '2 Column Left',
                        'img' => ReduxFramework::$_url . 'assets/img/2cl.png'
                    ),
                    '3' => array(
                        'alt' => '2 Column Right',
                        'img' => ReduxFramework::$_url . 'assets/img/2cr.png'
                    ),

                ),
                'default'  => '3'
            ),

        ),
    ) );
    
    /* End Page option */
    
    // -> START Woo Page Option

    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Woocommerce Page', 'virtusky' ),
        'id'         => 'virsky_woo_page_page',
        'icon'  => 'el el-shopping-cart',
        'fields'     => array(
            array(
                'id'       => 'virsky_woo_page_sidebar',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Set WooCommerce Page sidebar', 'virtusky' ),
                'subtitle' => esc_html__( 'Choose your Woocommerce page sidebar', 'virtusky' ),
                //Must provide key => value(array:title|img) pairs for radio options
                'options'  => array(
                    '1' => array(
                        'alt' => '1 Column',
                        'img' => ReduxFramework::$_url . 'assets/img/1col.png'
                    ),
                    '2' => array(
                        'alt' => '2 Column Left',
                        'img' => ReduxFramework::$_url . 'assets/img/2cl.png'
                    ),
                    '3' => array(
                        'alt' => '2 Column Right',
                        'img' => ReduxFramework::$_url . 'assets/img/2cr.png'
                    ),

                ),
                'default'  => '3'
            ),
			array(
                'id'       => 'virsky_woo_product_col',
                'type'     => 'select',
                'title'    => esc_html__( 'Product Column Set', 'virtusky' ),
                'options'  => array(
					'6' => '2 Column',
					'4' => '3 Column',
					'3' => '4 Column'
				),
				'default' => '4'
            ),
			array(
                'id'       => 'virsky_woo_product_perpage',
                'type'     => 'text',
                'title'    => esc_html__( 'Product Per Page', 'virtusky' ),
				'default' => '10'
            ),
			array(
                'id'       => 'virsky_woo_shoptitle_switch',
                'type'     => 'switch',
                'title'    => esc_html__( 'Shop page title on/off', 'virtusky' ),
                'subtitle' => esc_html__( 'Use switch to show or hide WooCommerce shop page title .', 'virtusky' ),
                'default'  => false,
            ),
			array(
                'id'       => 'virsky_woo_relproduct_num',
                'type'     => 'text',
                'title'    => esc_html__( 'Related products number', 'virtusky' ),
                'subtitle' => esc_html__( 'Set how many related products you want to show in single product page.', 'virtusky' ),
                'default'  => 3,
            ),


        ),
    ) );
    
    /* End Woo Page option */
    
    // -> START 404 Page

    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( '404 Page', 'virtusky' ),
        'id'         => 'virsky_404_page',
        'icon'       => 'el el-ban-circle',
        'fields'     => array(
            array(
                'id'       => 'virsky_fof_text',
                'type'     => 'text',
                'title'    => esc_html__( '404 Text', 'virtusky' ),
                'subtitle' => esc_html__( 'Set 404 text ', 'virtusky' ),
                'default'  => '404',                
            ),
            array(
                'id'       => 'virsky_fof_desc',
                'type'     => 'text',
                'title'    => esc_html__( '404 Description', 'virtusky' ),
                'subtitle' => esc_html__( 'Set 404 description text ', 'virtusky' ),
                'default'  => 'It looks like nothing was found at this location. Maybe try one of the links below or a search?',                
            ),
            array(
                'id'       => 'virsky_fof_background',
                'type'     => 'background',
                'output'   => array( '#f0f' ),
                'title'    => esc_html__( '404 Background', 'virtusky' ),
                'subtitle' => esc_html__( '404 page background with image, color, etc.', 'virtusky' ),
                'default'  => array(
                    'background-color' => '#5299d8',
                ),
            ),
            array(
                'id'       => 'virsky_fof_bgoverlay',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Background Overlay', 'virtusky' ),
                'subtitle' => esc_html__( 'Set background ovelay.', 'virtusky' ),
            ),
			array(
                'id'       => 'virsky_fof_overlay_color',
                'type'     => 'background',
                'output'   => array( '#f0f.bg--overlay:before' ),
                'title'    => esc_html__( 'Overlay Color', 'virtusky' ),
                'subtitle' => esc_html__( 'Set overlay color.', 'virtusky' ),
				'background-image' 		=> false,
				'background-size' 		=> false,
				'background-attachment' => false,
				'background-repeat' 	=> false,
				'background-position' 	=> false,
				'preview' 				=> false,
                'default'  => array(
                    'background-color' => '#288feb',
                ),
            ),
			array(
				'id' => 'virsky_fof_ovopacity',
				'type' => 'slider',
				'title' => esc_html__('Overlay Opacity', 'virtusky'),
				'subtitle' => esc_html__('set overlay opacity.', 'virtusky'),
				"default" => .5,
				"min" => 0,
				"step" => .1,
				"max" => 1,
				'resolution' => 0.1,
				'display_value' => 'text'
			),
        ),
    ) );
    
    /* End 404 Page */
    
    // -> START Page

    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Subscribe', 'virtusky' ),
        'id'         => 'virsky_subscribe_page',
        'icon'       => 'el el-eject',
        'fields'     => array(
            array(
                'id'       => 'virsky_subscribe_apikey',
                'type'     => 'text',
                'title'    => esc_html__( 'Mailchimp API Key', 'virtusky' ),
                'subtitle' => esc_html__( 'Set mailchimp api key.', 'virtusky' )              
            ),
            array(
                'id'       => 'virsky_subscribe_listid',
                'type'     => 'text',
                'title'    => esc_html__( 'Mailchimp List ID', 'virtusky' ),
                'subtitle' => esc_html__( 'Set mailchimp list id.', 'virtusky' )              
            ),

        ),
    ) );
    
    /* End Page */
    

    // -> START Contact Page   
    
    // -> START Social Media

    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Social', 'virtusky' ),
        'id'         => 'virsky_social_media',
        'icon'  => 'el el-globe',
        'fields'     => array(
            array(
                'id'       => 'virsky_facebook_link',
                'type'     => 'text',
                'title'    => esc_html__( 'Facebook', 'virtusky' ),
                'subtitle' => esc_html__( 'Add Facebook URL', 'virtusky' ),
            ),
            array(
                'id'       => 'virsky_twitter_link',
                'type'     => 'text',
                'title'    => esc_html__( 'Twitter', 'virtusky' ),
                'subtitle' => esc_html__( 'Add Twitter URL', 'virtusky' ),
            ),
            array(
                'id'       => 'virsky_google_link',
                'type'     => 'text',
                'title'    => esc_html__( 'Google Plus', 'virtusky' ),
                'subtitle' => esc_html__( 'Add google plus URL', 'virtusky' ),
            ),
            array(
                'id'       => 'virsky_youtube_link',
                'type'     => 'text',
                'title'    => esc_html__( 'Youtube', 'virtusky' ),
                'subtitle' => esc_html__( 'Add youtube URL', 'virtusky' ),
            ),
            array(
                'id'       => 'virsky_instagram_link',
                'type'     => 'text',
                'title'    => esc_html__( 'Instagram', 'virtusky' ),
                'subtitle' => esc_html__( 'Add Instagram URL', 'virtusky' ),
            ),
            array(
                'id'       => 'virsky_vimeo_link',
                'type'     => 'text',
                'title'    => esc_html__( 'Vimeo', 'virtusky' ),
                'subtitle' => esc_html__( 'Add vimeo plus URL', 'virtusky' ),
            ),
            array(
                'id'       => 'virsky_linkedin_link',
                'type'     => 'text',
                'title'    => esc_html__( 'Linkedin', 'virtusky' ),
                'subtitle' => esc_html__( 'Add linkedin plus URL', 'virtusky' ),
            ),
            array(
                'id'       => 'virsky_behance_link',
                'type'     => 'text',
                'title'    => esc_html__( 'Behance', 'virtusky' ),
                'subtitle' => esc_html__( 'Add behance plus URL', 'virtusky' ),
            ),          
            array(
                'id'       => 'virsky_pinterest_link',
                'type'     => 'text',
                'title'    => esc_html__( 'Pinterest', 'virtusky' ),
                'subtitle' => esc_html__( 'Add pinterest plus URL', 'virtusky' ),
            ),          
            array(
                'id'       => 'virsky_dribbble_link',
                'type'     => 'text',
                'title'    => esc_html__( 'Dribbble', 'virtusky' ),
                'subtitle' => esc_html__( 'Add dribbble plus URL', 'virtusky' ),
            ),          
            array(
                'id'       => 'virsky_github_link',
                'type'     => 'text',
                'title'    => esc_html__( 'Github', 'virtusky' ),
                'subtitle' => esc_html__( 'Add github URL', 'virtusky' ),
            ), 
        ),
    ) );
    
    /* End social Media */
    
    // -> START Footer Media

    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Footer', 'virtusky' ),
        'id'         => 'virsky_footer_section',
        'icon'  => 'el el-photo',
        'fields'     => array(
			array(
			   'id' => 'suooprt_section-start',
			   'type' => 'section',
			   'title' => __('Support Info Box Settings', 'virtusky'),
			   'indent' => true 
			),
		    array(
                'id'       => 'virsky_footer_supportinfo_en_dopt',
                'type'     => 'switch',
                'title'    => esc_html__( 'Support Info Enabled/Disabled', 'virtusky' ),
                'subtitle' => esc_html__( 'Enabled/Disabled footer support info box for all page.', 'virtusky' ),
                'default'  => 0,
                'on'       => 'Enabled',
                'off'      => 'Disabled',
            ),
			array(
                'id'       => 'virsky_footer_supportinfo_mob_dopt',
                'type'     => 'switch',
                'title'    => esc_html__( 'Support Info Enabled/Disabled in mobile view', 'virtusky' ),
                'subtitle' => esc_html__( 'Enabled/Disabled footer support info box for all page in mobile view.', 'virtusky' ),
                'default'  => 0,
                'on'       => 'Enabled',
                'off'      => 'Disabled',
            ),
			array(
                'id'          => 'virsky_supportbox',
                'type'        => 'slides',
                'title'       => esc_html__( 'Support Info Box', 'virtusky' ),
				'required' => array( 'virsky_footer_supportinfo_en_dopt', 'equals', 1 ),
                'subtitle'    => esc_html__( 'Add support info.', 'virtusky' ),
                'show'        => array( 
                    'title'          => true,
                    'description'    => false,
                    'progress'       => false,
                    'icon'           => true,
                    'facts-number'   => false,
                    'project-button' => false,
                    'facts-number-3' => false,
                    'facts-title3'   => false,
                    'facts-number-2' => false,
                    'facts-title2'   => false,
                    'facts-title1'   => false,
                    'url'            => true,
                    'image_upload'   => false,
                ),
                'placeholder' => array(
                    'icon' => esc_html__( 'Icon Class. Use font awesome icon like( fa-home ).', 'virtusky' ),
                    'title' => esc_html__( 'Info.', 'virtusky' ),
                    'url'   => esc_html__( 'url', 'virtusky' ),
                )
            ),
			array(
				'id'     => 'suooprt_section-end',
				'type'   => 'section',
				'indent' => false,
			),
            array(
                'id'       => 'virsky_footer_widget_disabled',
                'type'     => 'switch',
                'title'    => esc_html__( 'Footer Widgets Enabled/Disabled', 'virtusky' ),
                'subtitle' => esc_html__( 'Disabled footer Widgets section  ', 'virtusky' ),
                'default'  => 1,
                'on'       => 'Enabled',
                'off'      => 'Disabled',
            ),
            array(
                'id'       => 'virsky_footer_widget_background',
                'type'     => 'background',
                'output'   => array( '#footer' ),
                'title'    => esc_html__( 'Footer Widgets Background', 'virtusky' ),
                'subtitle' => esc_html__( 'Footer Widgets section background with image, color, etc.', 'virtusky' ),
                'required' => array( 'virsky_footer_widget_disabled', 'equals', 1 ),
                'default'  => array(
                    'background-color' => '#1d1d21',
                ),
            ),
			array(
                'id'       => 'virsky_footer_widget_ovswitch',
                'type'     => 'switch',
                'title'    => esc_html__( 'Footer Widgets Overlay Enabled/Disabled', 'virtusky' ),
				'required' => array( 'virsky_footer_widget_disabled', 'equals', 1  ),
                'default'  => 1,
                'on'       => 'Enabled',
                'off'      => 'Disabled',
            ),
			array(
                'id'       => 'virsky_footer_widget_ovcolor',
                'type'     => 'color',
				'required' => array( 'virsky_footer_widget_ovswitch', 'equals', 1  ),
                'title'    => esc_html__( 'Footer Widgets Overlay Color', 'virtusky' ),
                'subtitle' => esc_html__( 'Set footer widgets overlay color', 'virtusky' )
            ),
			array(
				'id' => 'virsky_footer_widget_ovopct',
				'type' => 'slider',
				'required' => array( 'virsky_footer_widget_ovswitch', 'equals', 1  ),
				'title'    => esc_html__( 'Footer Widgets Overlay Opacity', 'virtusky' ),
				'subtitle' => esc_html__( 'Set footer widgets overlay opacity', 'virtusky' ),
				"default" => .5,
				"min" => 0,
				"step" => .1,
				"max" => 1,
				'resolution' => 0.1,
				'display_value' => 'text'
			),
            array(
                'id'       => 'virsky_footer_widget_color',
                'type'     => 'color',
				'required' => array( 'virsky_footer_widget_disabled', 'equals', 1 ),
				'output'   => array( '#footer', '.footer-widget ul li a', '.footer-widget caption' ),
                'title'    => esc_html__( 'Footer Widget Text Color', 'virtusky' ),
                'subtitle' => esc_html__( 'Set footer widget text color', 'virtusky' )
            ),
            array(
                'id'       => 'virsky_copyright_text',
                'type'     => 'text',
                'title'    => esc_html__( 'Copyright', 'virtusky' ),
                'subtitle' => esc_html__( 'Add Copyright ', 'virtusky' ),
                'default'  => wp_kses_post( sprintf( __( 'Copyright &copy; %s <a href="#">VirtuSky</a>. All Rights Reserved.', 'virtusky' ),date('Y') ) ),
            ),
            array(
                'id'       => 'virsky_payment_img',
                'type'     => 'media',
                'title'    => esc_html__( 'Payment Method', 'virtusky' ),
                'subtitle' => esc_html__( 'Set paymet method image', 'virtusky' )
            ),
            array(
                'id'       => 'virsky_footer_copyright_background',
                'type'     => 'background',
                'output'   => array( '#copyright' ),
                'title'    => esc_html__( 'Footer Background', 'virtusky' ),
                'subtitle' => esc_html__( 'Footer section background with image, color, etc.', 'virtusky' ),
            ),
            array(
                'id'       => 'virsky_footer_copyright_color',
                'type'     => 'color',
				'output'   => array( '#copyright' ),
                'title'    => esc_html__( 'Footer Text Color', 'virtusky' ),
                'subtitle' => esc_html__( 'Set footer text color', 'virtusky' )
            ),
            
        ),
    ) );
    
    /* End Footer Media */

    /*
     * <--- END SECTIONS
     */


    /*
     *
     * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
     *
     */

    /*
    *
    * --> Action hook examples
    *
    */

    // If Redux is running as a plugin, this will remove the demo notice and links
    //add_action( 'redux/loaded', 'remove_demo' );

    // Function to test the compiler hook and demo CSS output.
    // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
    //add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);

    // Change the arguments after they've been declared, but before the panel is created
    //add_filter('redux/options/' . $opt_name . '/args', 'change_arguments' );

    // Change the default value of a field after it's been set, but before it's been useds
    //add_filter('redux/options/' . $opt_name . '/defaults', 'change_defaults' );

    // Dynamically add a section. Can be also used to modify sections/fields
    //add_filter('redux/options/' . $opt_name . '/sections', 'dynamic_section');

    /**
     * This is a test function that will let you see when the compiler hook occurs.
     * It only runs if a field    set with compiler=>true is changed.
     * */
    if ( ! function_exists( 'compiler_action' ) ) {
        function compiler_action( $options, $css, $changed_values ) {
            echo '<h1>'.esc_html__( 'The compiler hook has run!', 'virtusky' ).'</h1>';
            echo "<pre>";
            print_r( $changed_values ); // Values that have changed since the last save
            echo "</pre>";
            //print_r($options); //Option values
            //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )
        }
    }

    /**
     * Custom function for the callback validation referenced above
     * */
    if ( ! function_exists( 'redux_validate_callback_function' ) ) {
        function redux_validate_callback_function( $field, $value, $existing_value ) {
            $error   = false;
            $warning = false;

            //do your validation
            if ( $value == 1 ) {
                $error = true;
                $value = $existing_value;
            } elseif ( $value == 2 ) {
                $warning = true;
                $value   = $existing_value;
            }

            $return['value'] = $value;

            if ( $error == true ) {
                $return['error'] = $field;
                $field['msg']    = esc_html__( 'your custom error message', 'virtusky' );
            }

            if ( $warning == true ) {
                $return['warning'] = $field;
                $field['msg']      = esc_html__( 'your custom warning message', 'virtusky' );
            }

            return $return;
        }
    }

    /**
     * Custom function for the callback referenced above
     */
    if ( ! function_exists( 'redux_my_custom_field' ) ) {
        function redux_my_custom_field( $field, $value ) {
            print_r( $field );
            echo '<br/>';
            print_r( $value );
        }
    }

    /**
     * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
     * Simply include this function in the child themes functions.php file.
     * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
     * so you must use get_template_directory_uri() if you want to use any of the built in icons
     * */
    if ( ! function_exists( 'dynamic_section' ) ) {
        function dynamic_section( $sections ) {
            //$sections = array();
            $sections[] = array(
                'title'  => esc_html__( 'Section via hook', 'virtusky' ),
                'desc'   => wp_kses( __( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'virtusky' ), $alowhtml),
                'icon'   => 'el el-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }
    }

    /**
     * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
     * */
    if ( ! function_exists( 'change_arguments' ) ) {
        function change_arguments( $args ) {
            //$args['dev_mode'] = true;

            return $args;
        }
    }

    /**
     * Filter hook for filtering the default value of any given field. Very useful in development mode.
     * */
    if ( ! function_exists( 'change_defaults' ) ) {
        function change_defaults( $defaults ) {
            $defaults['str_replace'] = esc_html__( 'Testing filter hook!', 'virtusky' );

            return $defaults;
        }
    }

